@@ -97,11 +97,11 @@ fn extension_module_shared_library_create_module(
     // Any error past this point should call `MemoryFreeLibrary()` to unload the
     // library.
 
-    load_dynamic_library(py, sys_modules, spec, name_py, name, module).or_else(|e| {
+    load_dynamic_library(py, sys_modules, spec, name_py, name, module).map_err(|e| {
         unsafe {
             free_library_memory(module);
         }
-        Err(e)
+        e
     })
 }
 
@@ -163,16 +163,14 @@ fn load_dynamic_library(
         py_module
     };
 
-    if py_module.is_null() {
-        if unsafe { pyffi::PyErr_Occurred().is_null() } {
-            return Err(PyErr::new::<SystemError, _>(
-                py,
-                format!(
-                    "initialization of {} failed without raising an exception",
-                    name
-                ),
-            ));
-        }
+    if py_module.is_null() && unsafe { pyffi::PyErr_Occurred().is_null() } {
+        return Err(PyErr::new::<SystemError, _>(
+            py,
+            format!(
+                "initialization of {} failed without raising an exception",
+                name
+            ),
+        ));
     }
 
     // Cast to owned type to help prevent refcount/memory leaks.
